%% Assign SLP objective function
% This is the objective function of the peak assignment.
% It uses the possible peak assignment and back calculates
% to determine the rmsd.

% The objective function can be changed to use the
% chemical shifts by uncommenting.

% The program uses a cell array.

function FitnessFcn=Assign_SLP_objective_function(x,DataStruct)

FitnessFcn = zeros(size(x,1),1);

for j = 1:size(x,1)    
    d = x{j};    
    y=zeros(1,DataStruct.number_media);    
    noe_objective=zeros(1,DataStruct.number_media);
    
    for media=1:DataStruct.number_media        
        % The d is a single element of the cell array.  There are
        % population_size elements of the cell array.        
        clear temp;       
                    
            total=0;
            
            % rearrange D
            D_new = DataStruct.D(media,d);
            
            D_errors = DataStruct.D(media,(DataStruct.number_measurements+1):end);
            D_errors = D_errors(d);
            
            notMissing = D_new ~=999;
            total = sum(notMissing);
            


            % filter out 'missing' residue coordinates
            x_new = DataStruct.xcoordinate(notMissing);
            y_new = DataStruct.ycoordinate(notMissing);
            z_new = DataStruct.zcoordinate(notMissing);

            % filter out missing RDCs
            D_new = D_new(notMissing);
            D_errors = D_errors(notMissing);

            if DataStruct.validation=="false"
                DS = D_new./DataStruct.order_parameters(notMissing)';                        
            elseif DataStruct.validation=="true"
                DS = D_new;
            end
            
            a = zeros(total,5);
            
            % generate matrix of independent spatial terms
            a(:,1) = (y_new.^2 - x_new.^2)';
            a(:,2) = (z_new.^2 - x_new.^2)';
            a(:,3) = 2*(x_new.*y_new)';
            a(:,4) = 2*(x_new.*z_new)';
            a(:,5) = 2*(y_new.*z_new)';

            b = DS / DataStruct.Dmax .* vecnorm([x_new', y_new', z_new'],2,2).^5; % vecnorm call calculates the magnitude of each row
            
            yy=lscov(a,b');   %computing projection of matrix A on b, giving x
            
            back_calc = a * yy;
            
            RDC_score = sum(((back_calc - b') ./ D_errors').^2);
            y(media)=sqrt(RDC_score/total)*(total-5)/DataStruct.number_measurements;
    end
    
 % noe
    total=0;

    for i=1:DataStruct.number_measurements
        if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0
            if DataStruct.Qexp(1,d(i))~=999
                if DataStruct.Qpred(1,i)~=999
                    if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0
                        total=total+1;
                    end
                end
            end
        end
    end
    
    for i=1:DataStruct.number_measurements
        if DataStruct.Qexp(1,d(i))~=999
            if DataStruct.Qpred(1,i)~=999
                if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0
                    noe_objective(media)=noe_objective(media)+(1-DataStruct.QQ(d(i),i))^2;
                end
            end
        end
    end
    noe_objective(media) = DataStruct.noe_factor*(total/DataStruct.number_measurements)*sqrt(noe_objective(media)/total);   
    
    % The nitrogen chemical shift is added.    
    total=0;
    
    for i=1:DataStruct.number_measurements        
        if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0            
            if DataStruct.nitrogen(d(i))~=999                
                if DataStruct.nitrogen(i+DataStruct.number_measurements)~=999                    
                    total=total+1;                    
                end                
            end            
        end        
    end    
    
    nitrogen_objective=0;
    
    for i=1:DataStruct.number_measurements        
        if DataStruct.nitrogen(d(i))~=999            
            if DataStruct.nitrogen(i+DataStruct.number_measurements)~=999                
                if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0                    
                    nitrogen_objective=nitrogen_objective+(DataStruct.nitrogen(d(i))-DataStruct.nitrogen(DataStruct.number_measurements+i))*(DataStruct.nitrogen(d(i))-DataStruct.nitrogen(DataStruct.number_measurements+i))/DataStruct.nitrogen(2*DataStruct.number_measurements+i)/DataStruct.nitrogen(2*DataStruct.number_measurements+i);                    
                end                
            end            
        end        
    end
    
    nitrogen_objective=(total/DataStruct.number_measurements)*sqrt(nitrogen_objective/total);    
    
    % The hydrogen chemical shift is added.    
    total=0;
    
    for i=1:DataStruct.number_measurements        
        if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0            
            if DataStruct.hydrogen(d(i))~=999                
                if DataStruct.hydrogen(i+DataStruct.number_measurements)~=999                    
                    total=total+1;                    
                end                
            end            
        end        
    end
    
    hydrogen_objective=0;
    for i=1:DataStruct.number_measurements        
        if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0            
            if DataStruct.hydrogen(d(i))~=999                
                if DataStruct.hydrogen(i+DataStruct.number_measurements)~=999                    
                    hydrogen_objective=hydrogen_objective+(DataStruct.hydrogen(d(i))-DataStruct.hydrogen(DataStruct.number_measurements+i))*(DataStruct.hydrogen(d(i))-DataStruct.hydrogen(DataStruct.number_measurements+i))/DataStruct.hydrogen(2*DataStruct.number_measurements+i)/DataStruct.hydrogen(2*DataStruct.number_measurements+i);                    
                end                
            end            
        end        
    end
    
    hydrogen_objective=(total/DataStruct.number_measurements)*sqrt(hydrogen_objective/total);    
    
    % add the media rdc,noe's    
    fitness=0;
    
    for media=1:DataStruct.number_media        
        fitness=fitness+y(media) + DataStruct.noe_factor * noe_objective(media);        
    end
    
    fitness=fitness+nitrogen_objective+hydrogen_objective;
    
    for i=1:DataStruct.number_measurements        
        if DataStruct.constraint_assignment(d(i),i)==0            
            fitness = fitness + DataStruct.penalty;            
        end        
    end    
    FitnessFcn(j)=fitness;    
end


