function [best_x,best, exitflag,bestPop,bestScores] = assignSLPvalidate(DataStruct,dataFlags)
% assignSLPsearch - wrapper script to setup genetic algorithm assignment
% search using the ga function
%
% Input
%       DataStruct
%       dataFlags
% Output
%       DataStruct
%       exitFlag
%       finalPop
%       finalScores

% initialize data type flags
useCS = false; useRDC = false; useNOE = false; usePRE = false; usePCS = false; useRDCPCS = false;

for i = 1:size(dataFlags,2)
    if strcmp(dataFlags{i},'CS')
        useCS = true;
    elseif strcmp(dataFlags{i},'RDC')
        useRDC = true;
    elseif strcmp(dataFlags{i},'NOE')
        useNOE = true;
    elseif strcmp(dataFlags{i},'PRE')
        usePRE = true;
    elseif strcmp(dataFlags{i},'PCS')
        usePCS = true;
    elseif strcmp(dataFlags{i},'RDC+PCS')
        useRDCPCS = true;
    end
end

% nvars is the total of measured and calculated
% nvars=size(DataStruct.D,2);

% number_measurements=nvars(1)/2;
DataStruct.number_measurements= size(DataStruct.hydrogen,2)/3;

if useRDC
    DataStruct.xcoordinate=zeros(DataStruct.number_measurements,1);
    DataStruct.ycoordinate=zeros(DataStruct.number_measurements,1);
    DataStruct.zcoordinate=zeros(DataStruct.number_measurements,1);
    DataStruct.order_parameters=zeros(DataStruct.number_measurements,1);
    
    measurements=zeros(DataStruct.number_measurements,1);
    
    for i=1:DataStruct.number_measurements
        
        DataStruct.xcoordinate(i)=DataStruct.coordinate(i,1)-DataStruct.coordinate(i,4);
        DataStruct.ycoordinate(i)=DataStruct.coordinate(i,2)-DataStruct.coordinate(i,5);
        DataStruct.zcoordinate(i)=DataStruct.coordinate(i,3)-DataStruct.coordinate(i,6);
        DataStruct.Dmax(i) = DataStruct.coordinate(i,7);
        DataStruct.order_parameters(i)=DataStruct.coordinate(i,8);
    end
end

if useNOE
    DataStruct.QQ=zeros(DataStruct.number_measurements,DataStruct.number_measurements);
    
    for i=1:DataStruct.number_measurements
        for j=1:DataStruct.number_measurements
            if DataStruct.Qexp(1,i)~=999
                if DataStruct.Qpred(1,j)~=999
                    temporary=corrcoef(DataStruct.Qexp(:,i),DataStruct.Qpred(:,j));
                    DataStruct.QQ(i,j)=temporary(1,2);
                end
            end
        end
    end
end

% Construct fitness function using desired data types
%
FitnessFcn = @(x) slpPenalty(x,DataStruct) + residuePairPenalty(x,DataStruct);

if useCS
    FitnessFcn = @(x) FitnessFcn(x) + chemshiftScore(x,DataStruct);
end

if useRDC
    FitnessFcn = @(x) FitnessFcn(x) + rdcScore(x,DataStruct);
end

if useNOE
    FitnessFcn = @(x) FitnessFcn(x) + noeScore(x,DataStruct);
end

if usePRE
    FitnessFcn = @(x) FitnessFcn(x) + preScore(x,DataStruct);
end

if usePCS
    FitnessFcn = @(x) FitnessFcn(x) + pcsScore(x,DataStruct);
end

if useRDCPCS
    FitnessFcn = @(x) FitnessFcn(x) + rdcpcsScore(x,DataStruct);
end

% Genetic Algorithm
% This will create an options structure using the cell array
% and the population range.  The population size is used; the population
% is randomly chosen using the population creation function.
options = optimoptions(@ga,'PopulationSize',DataStruct.population_size, ...
    'PopulationType', 'custom',...
    'CreationFcn',@create_permutations, ...
    'CrossoverFcn',@crossover_permutation,...
    'MutationFcn',@mutate_permutation, ...
    'Generations',DataStruct.max_generations, ...
    'StallGenLimit',DataStruct.gen_limit,...
    'Vectorized','on', ...
    'EliteCount',.05*DataStruct.population_size,...
    'CrossoverFraction',0.2); % hard-coded, seems to have little effect on search

    nRounds = DataStruct.nSearch;
    numberOfVariables = DataStruct.number_measurements;
    best = [];
for i = 1:nRounds        
    [x,fval,exitflag,~,finalPop,finalScores] = ga(FitnessFcn,numberOfVariables,[],[],[],[],[],[],[],options);
    
    % check for user termination
    if exitflag == -1
        return
    end
    
    if isempty(best)
        best = fval;
        best_x = x;
        bestPop = finalPop;
        bestScores = finalScores;
    elseif fval < best
        best_x = x;
        best = fval;
        bestPop = finalPop;
        bestScores = finalScores;
    end
end
end