%% chemshiftScore - Calculate Chemical Shift scoring function for AssignSLPGUI
% inputs
%   x - cell array containing assignment vectors,
%           n x 1 cell array of 1x12 double
%
%   DataStruct - structure variable used throughout the AssignSLPGUI code
%
% output
%   score - vector containing scores of all assignments, n x 1 double
function score = chemshiftScore(x,DataStruct)

score = zeros(size(x,1),1);

for j = 1:size(x,1)    
    d = x{j};    
        
    Nscore = 0;
    Hscore = 0;
    
    total = 0;
    for i=1:DataStruct.number_measurements
%         if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0
            if DataStruct.nitrogen(d(i))~=999
                if DataStruct.nitrogen(i+DataStruct.number_measurements)~=999
                    total=total+1;
                end
            end
%         end
    end
    
    for i=1:DataStruct.number_measurements        
        if DataStruct.nitrogen(d(i))~=999            
            if DataStruct.nitrogen(i+DataStruct.number_measurements)~=999                
%                 if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0                    
                    Nscore = Nscore + ...
                        (DataStruct.nitrogen(d(i))-DataStruct.nitrogen(DataStruct.number_measurements+i))*...
                        (DataStruct.nitrogen(d(i))-DataStruct.nitrogen(DataStruct.number_measurements+i))/...
                        DataStruct.nitrogen(2*DataStruct.number_measurements+i)/...
                        DataStruct.nitrogen(2*DataStruct.number_measurements+i);                    
%                 end                
            end            
        end        
    end
    
    Nscore=(total/DataStruct.number_measurements)*sqrt(Nscore/total);    
    
    % The hydrogen chemical shift is added.    
    total=0;
    
    for i=1:DataStruct.number_measurements        
%         if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0            
            if DataStruct.hydrogen(d(i))~=999                
                if DataStruct.hydrogen(i+DataStruct.number_measurements)~=999                    
                    total=total+1;                    
                end                
            end            
%         end        
    end
    
    for i=1:DataStruct.number_measurements        
%         if DataStruct.xcoordinate(i)*DataStruct.ycoordinate(i)*DataStruct.zcoordinate(i)~=0            
            if DataStruct.hydrogen(d(i))~=999                
                if DataStruct.hydrogen(i+DataStruct.number_measurements)~=999                    
                    Hscore=Hscore+(DataStruct.hydrogen(d(i))-DataStruct.hydrogen(DataStruct.number_measurements+i))*(DataStruct.hydrogen(d(i))-DataStruct.hydrogen(DataStruct.number_measurements+i))/DataStruct.hydrogen(2*DataStruct.number_measurements+i)/DataStruct.hydrogen(2*DataStruct.number_measurements+i);                    
                end                
            end            
%         end        
    end
    
    Hscore=(total/DataStruct.number_measurements)*sqrt(Hscore/total);    

        
    %     fitness = DataStruct.nitrogenWeight * Nscore + DataStruct.protonWeight * Hscore;
    fitness = Nscore + Hscore;
    
    score(j)=fitness;    
end
end

function score = rmsdScore(expt,pred,error)
%% rsmdScore - returns RMSD between two vectors, weighted by errors

% expt - vector of experimental data
% pred - vector of predicted data
% error - vector of errors

score = sum((expt - pred).^2 ./ error.^2);


end