function xoverKids  = crossover_permutation(parents,options,NVARS, ...
    FitnessFcn,thisScore,thisPopulation)
%   CROSSOVER_PERMUTATION Custom crossover function for traveling salesman.
%   XOVERKIDS = CROSSOVER_PERMUTATION(PARENTS,OPTIONS,NVARS, ...
%   FITNESSFCN,THISSCORE,THISPOPULATION) crossovers PARENTS to produce
%   the children XOVERKIDS.
%
%   The arguments to the function are 
%     PARENTS: Parents chosen by the selection function
%     OPTIONS: Options structure created from GAOPTIMSET
%     NVARS: Number of variables 
%     FITNESSFCN: Fitness function 
%     STATE: State structure used by the GA solver 
%     THISSCORE: Vector of scores of the current population 
%     THISPOPULATION: Matrix of individuals in the current population

%   Copyright 2004 The MathWorks, Inc. 
%   Updated by Varshith 6/6/2022

nKids = length(parents)/2;
xoverKids = cell(nKids,1); % Normally zeros(nKids,NVARS);
i=1;
while i <= nKids
    % here is where the special knowledge that the population is a cell
    % array is used. Normally, this would be thisPopulation(parents(index),:);
    index1 = randsample((nKids*2),1);
    parent1 = thisPopulation{parents(index1)};
    index2 = randsample(nKids*2,1);
    parent2 = thisPopulation{parents(index2)};
    
    if index1 == index2
        continue
    end
    
    % cut point is AFTER this index.
    xOverPoint = ceil(rand * (length(parent1) - 1));
    p1 = parent1(1:xOverPoint);
    p2 = parent2(1:xOverPoint);
    %Seeing if two segments on the parents match from index1 to break point
    if ~isequal(sort(p1),sort(p2))
        continue
    end
    %Swapping at the crossover point
    child = [parent1(1:xOverPoint),parent2(( xOverPoint + 1 ):  end )];
    xoverKids{i} = child; % Normally, xoverKids(i,:);
    i = i +1;
end


    
