% getRDCcoords -

function RDCcoords = getRDCcoords(pdb,resTarget,proton,hetAtom,Dmax)

% grab coordinates for spin pair of interest, e.g. 1H-15
for i = 1:size(resTarget,2)
    if ~isempty(resTarget{i})
        resI = selectname(pdb.resname,resTarget{i});


        atom1 = find(selectname(pdb.name,proton{i})  & resI & (ismissing(cellstr(pdb.altloc)) | selectname(pdb.altloc,'A')));
        atom2 = find(selectname(pdb.name,hetAtom{i}) & resI & (ismissing(cellstr(pdb.altloc)) | selectname(pdb.altloc,'A')));

        % convert to one-letter amino acid code
        res = aminolookup(strtrim(pdb.resname(atom1,:)))';
        
        % define variables to package into table
        Residue = strcat(res,int2str(pdb.resseq(atom1,:)));
        atom1XYZ = pdb.xyz(atom1,:);
        atom2XYZ = pdb.xyz(atom2,:);
        
        OrderParm = ones(size(Residue,1),1);
        if i == 1
            RDCcoords = table(string(Residue),...
                atom1XYZ(:,1),atom1XYZ(:,2),atom1XYZ(:,3),...
                atom2XYZ(:,1),atom2XYZ(:,2),atom2XYZ(:,3),...
                Dmax(i)*ones(size(Residue,1),1),...
                OrderParm,...
                'VariableNames',{'Residue','x1','y1','z1',' x2','y2','z2','Dmax','Order Parameter'});
        else
            tmpTable = table(string(Residue),...
                atom1XYZ(:,1),atom1XYZ(:,2),atom1XYZ(:,3),...
                atom2XYZ(:,1),atom2XYZ(:,2),atom2XYZ(:,3),...
                Dmax(i)*ones(size(Residue,1),1),...
                OrderParm,...
                'VariableNames',{'Residue','x1','y1','z1',' x2','y2','z2','Dmax','Order Parameter'});
            
            RDCcoords = [RDCcoords; tmpTable];
        end
    end
end
% sort by residue names, sortrows function seems to be broken for tables
[~,I] = sort(string(RDCcoords.Residue));
for i = 1:size(RDCcoords,2)
    RDCcoords(:,i) = RDCcoords(I,i);
end

end