%% importPredictions - created by RVW 9/16/2019
% Load predictions for Assign_SLP from Excel spreadsheet

% Input
%   fileName

% Output
%   predictions - struct containing prediction data

function predictions = importPredictions(fileName)
sheets = sheetnames(fileName);
[I,hsqcFound,coordsFound,NOEsFound,PREsFound] = checkSheets(sheets);

% Load Chemical Shifts
if hsqcFound
    hsqc = readcell(fileName,'Sheet','HSQC');
    predictions.hsqc = extractShifts(hsqc,'Assignment','HSQC');
else
    predictions.hsqc = [];
end

% Load Average Coordinates and Order parameters (for RDC
% back-calculation)
if coordsFound
    coords = readcell(fileName,'Sheet',I);
    temp = extractShifts(coords,'Residue','Coordinates & Order Parameters');
    predictions.coordinates = temp(1:end,:);
else
    predictions.coordinates = [];
end

% Load NOEs
%     NOE = readcell(fileName,'Sheet','NOEs - Strips');
%     predictions.NOEstrips = extractShifts(NOE,'Chemical Shift (ppm)','NOEs - Strips');

% Load NOEs from Sparky format peak list
if NOEsFound
    NOEsparky = readcell(fileName,'Sheet','NOEs');
    predictions.NOEsparky = extractShifts(NOEsparky,'Assignment','NOEs');
    [predictions.SparkyStrips,predictions.NOEpeaks] = sparky2strips(predictions.NOEsparky,0.4);
else
    predictions.SparkyStrips = [];
end

% Load PREs
if PREsFound
    PREs = readcell(fileName,'Sheet','PREs');
    predictions.PREs = extractShifts(PREs,'Residue','PREs');
    PCScoords = readcell(fileName,'Sheet','PCS');
    predictions.PCScoords = extractShifts(PCScoords,'Residue','PCS');
else
    predictions.PREs = [];
    predictions.PCScoords = [];
end

% Load Residue Pairing information
tmp = readcell(fileName,'Sheet','Intraresidue Pairing');
tmp = extractShifts(tmp,'Peak','Intraresidue Pairing');
predictions.residuePairs = tmp;

[predictions.SparkyStrips,predictions.NOEpeaks] = sparky2strips(predictions.NOEsparky,0.4);
end

function data = extractShifts(C,SearchFlag,SheetName)
% This subroutine ignores any header information and extracts all cells
% in rows after a specified label

[rows,~] = size(C);
for i = 1:rows
    if strcmp(C{i,1},SearchFlag)
        if strcmp(SearchFlag,'Assignment')
            startHere = i + 2;
        else
            startHere = i + 1;
        end
    end
end

if ~exist('startHere','var')
    error(['Problem parsing ',SheetName]);
end

data = C(startHere:end,:);
end

function [I,hsqcFound,coordsFound,NOEsFound,PREsFound] = checkSheets(sheets)
% check that sheets are properly named and throw error if not
% returns index for coordinates sheet
[rows,~] = size(sheets);

hsqcFound = false;
NOEsFound = false;
coordsFound = false;
PREsFound = false;

for i = 1:rows
    if strcmp(sheets{i},'HSQC')
        hsqcFound = true;
    elseif strcmp(sheets{i}(1:3),'Coo') % indexing past 3 characters throws an error for NOE
        coordsFound = true;
        I = i;
    elseif strcmp(sheets{i}(1:3),'NOE')
        NOEsFound = true;
    elseif strcmp(sheets{i},'PREs')
        PREsFound = true;
    end
end

% if ~hsqcFound
%     error('Could not find Chemical Shift data, check HSQC sheet name')
% end
% 
% if ~coordsFound
%     error('No Coordinates found, check sheet name')
% end
% 
% if ~NOEsFound
%     error('No NOE data found, check sheet name')
% end
end