% messagePDB - renames atoms to be consistent with
% ShiftX2 coventions and averages coordinates for equivalent protons, e.D.
% methyl groups
% 
% original code from J. Glushka, modified by R. Williams

% Input
%   NOEpairsList    table
% Output
%   newRes    table with renamed residues
%   newAtom   renamed atoms

function [newRes,newAtom] = messageMD(residues,atoms)
nPairs = size(residues,1);

% edit methyl group names (e.g. pdb: Leu HD11,HD12,HD13 -> shiftx2: HD1)
% LEU HD1 HD2, VAL HG, ILE HG2, ILE HD1, THR HB,  ALA HB, MET HE
% then average coordinates

for k=1:nPairs
    if residues(k,:) == "LEU " % LEU methyl protons
        atoms(k,:)= replace(atoms(k,:),["HD11","HD12","HD13"],"HD1 ");
        atoms(k,:)= replace(atoms(k,:),["HD21","HD22","HD23"],"HD2 ");
    end
    
    if residues(k,:) == "ILE "
        atoms(k,:)= replace(atoms(k,:),["HD11","HD12","HD13"],"HD1 ");
        atoms(k,:)= replace(atoms(k,:),["HG21","HG22","HG23"],"HG2 ");
    end
    
    if residues(k,:) == "VAL " % Val methyl protons
        atoms(k,:)= replace(atoms(k,:),["HG11","HG12","HG13"],"HG1 ");
        atoms(k,:)= replace(atoms(k,:),["HG21","HG22","HG23"],"HG2 ");
    end
    
    if residues(k,:) == "THR " % THR methyl proton
        atoms(k,:)= replace(atoms(k,:),["HG21","HG22","HG23"],"HG2 ");
    end
    
    if residues(k,:) == "ALA " % ALA methyl proton
        atoms(k,:)= replace(atoms(k,:),["HB1","HB2","HB3"],"HB ");
    end
    
    if residues(k,:) == "MET " % MET methyl proton
        atoms(k,:)= replace(atoms(k,:),["HE1","HE2","HE3"],"HE ");
    end
    
    if (residues(k,:) == "LYS " & strtrim(atoms(k,:)) == " HZ1") == 1  % LYS Z protons
        atoms(k,:)= replace(atoms(k,:)," HZ1","HZ  ");
    end
    
    % rename MD-specific residue codes, e.g. histidine, cysteine
    if (residues(k,:) == "HIE " || residues(k,:) == "HID ")
        residues(k,:) = "HIS ";
    end
    
    if residues(k,:) == "CYX "
        residues(k,:) = "CYS ";
    end
    
    if residues(k,:) == "NLN "
        residues(k,:) = "ASN ";
    end
end

newAtom= atoms;
newRes = residues;
end