% messagePDB - renames certain atoms in a PDB to be consistent with
% ShiftX2 coventions and averages coordinates for equivalent protons, e.g.
% methyl groups
% 
% original code from J. Glushka, modified by R. Williams

% Input
%   pdb     pdb struct prepared using MDToolbox readpdb function
% Output
%   newPDB  pdb struct with updated atom names and average pseudoatoms for
%           methyl groups

function newPDB = messagePDB(pdb)
nPdbAtoms = size(pdb.serial,1);                           %total no. atoms in pdb

% edit methyl group names (e.g. pdb: Leu HD11,HD12,HD13 -> shiftx2: HD1)
% LEU HD1 HD2, VAL HG, ILE HG2, ILE HD1, THR HB,  ALA HB, MET HE
% then average coordinates

for k=1:nPdbAtoms
    if (pdb.resname(k,:) == "LEU " & strtrim(pdb.name(k,:)) == "HD11") == 1  % LEU methyl protons
        pdb.name(k,:)= replace(pdb.name(k,:),"HD11","HD1 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;  %average coordinates
    end
    
    if (pdb.resname(k,:) == "LEU " & strtrim(pdb.name(k,:)) == "HD21") == 1  % LEU methyl protons
        pdb.name(k,:)= replace(pdb.name(k,:),"HD21","HD2 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;  %average coordinates
    end
    
    if (pdb.resname(k,:) == "ILE " & strtrim(pdb.name(k,:)) == "HD11") == 1  % ILE methyl protons
        pdb.name(k,:)= replace(pdb.name(k,:),"HD11","HD1 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end
    
    if (pdb.resname(k,:) == "ILE " & strtrim(pdb.name(k,:)) == "HG11") == 1  % ILE methyl protons
        pdb.name(k,:)= replace(pdb.name(k,:),"HG11","HG1 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end
    
    if (pdb.resname(k,:) == "VAL " & strtrim(pdb.name(k,:)) == "HG11") == 1  % Val methyl protons
        pdb.name(k,:)= replace(pdb.name(k,:),"HG11","HG1 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end

    if (pdb.resname(k,:) == "VAL " & strtrim(pdb.name(k,:)) == "HG21") == 1  % Val methyl protons
        pdb.name(k,:)= replace(pdb.name(k,:),"HG21","HG2 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end

    
    if (pdb.resname(k,:) == "THR " & strtrim(pdb.name(k,:)) == "HG21") == 1  % THR methyl proton
        pdb.name(k,:)= replace(pdb.name(k,:),"HG21","HG2 ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end
    
    if (pdb.resname(k,:) == "ALA " & strtrim(pdb.name(k,:)) == "HB1") == 1  % ALA methyl proton
        pdb.name(k,:)= replace(pdb.name(k,:)," HB1","HB  ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end
    
    if (pdb.resname(k,:) == "MET " & strtrim(pdb.name(k,:)) == "HE1") == 1  % MET methyl proton
        pdb.name(k,:)= replace(pdb.name(k,:),"HE1","HE ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end
    
    if (pdb.resname(k,:) == "LYS " & strtrim(pdb.name(k,:)) == " HZ1") == 1  % LYS Z protons
        pdb.name(k,:)= replace(pdb.name(k,:)," HZ1","HZ  ");
        pdb.xyz(k,:) = (pdb.xyz(k,:)+pdb.xyz(k+1,:)+pdb.xyz(k+2,:))./3;
    end
end
tmp = string(pdb.name);
pdb.name = strtrim(tmp);
pdb.name = char(pdb.name);
newPDB = pdb;
end