function plotHSQC(DataStruct)
%% plotHSQC - simulate a 2D contour plot using an HSQC peak list
%  
% Inputs
%       DataStruct      struct prepared by AssignSLP
% See Also
%       importData, importPredictions

% get HSQC peak List
H = DataStruct.hydrogen;
N = DataStruct.nitrogen;
nPeaks = size(H,2)/2;

HSQC = [N(1:nPeaks)',H(1:nPeaks)'];

%% determine ranges of plot 
low = min(HSQC);
high = max(HSQC);

low = low*0.95;
high = high*1.05;

wH = linspace(low(2),high(2),2048);
wN = linspace(low(1),high(1),256);
[X,Y] = meshgrid(wH,wN);

% define 2D gaussian
c1 = 0.1/2;
c2 = 0.4/2;

peak = zeros(256,2048);
for i = 1:nPeaks
    peak = peak + exp(-(X - HSQC(i,2)).^2 / c1^2) .* exp(-(Y - HSQC(i,1)).^2 / c2^2);
end

contour(X,Y,peak);
ax = gca;
ax.XDir = 'reverse';
ax.YDir = 'reverse';

xlabel('\omega_H (ppm)')
ylabel('\omega_N (ppm)')
end
