%% preScore - Calculate PRE scoring function for AssignSLPGUI
% inputs
%   x - cell array containing assignment vectors,
%           n x 1 cell array of 1x12 double
%
%   DataStruct - structure variable used throughout the AssignSLPGUI code
%
% output
%   score - vector containing scores of all assignments, n x 1 double
function score = preScore(x,DataStruct)

score = zeros(size(x,1),1);
expt = DataStruct.PRE(:,1);
pred = DataStruct.PRE(:,2);
err = DataStruct.PRE(:,3);

for j = 1:size(x,1)    
    d = x{j};  
    tmp_expt = expt(d); % rearrange experimental data
%     pred = pred(d); % rearrange predicted data?
    notMissing = (tmp_expt ~= 999) | (pred ~= 999);
    score(j) = rmsdScore(tmp_expt(notMissing),pred(notMissing),err(notMissing));
end
end

function score = rmsdScore(expt,pred,error)
%% rsmdScore - returns RMSD between two vectors, weighted by errors

% expt - vector of experimental data
% pred - vector of predicted data
% error - vector of errors

n = length(expt);
score = sqrt(sum((expt - pred).^2 ./ error.^2)/n); % RMSD
end