% create predicted HSQC info

function [predHSQCtable, HSQCedit] = predictHSQC(CS,resTarget,proton,hetAtom)
%% Generate predicted HSQC peak list

% loop over residues
HSQCedit = 0; %Used if some shifts are missing and causes an error
for i = 1:size(resTarget,2)
    % Some less than efficient code to find missing data for residues and
    % append them
    if ~isempty(resTarget{i})
        resI = selectname(CS.resName,resTarget{i});
        
        cs1_I = resI & selectname(CS.atomName,(proton{i}));
        cs2_I = resI & selectname(CS.atomName,(hetAtom{i}));
        cs1 = CS(cs1_I,:);
        cs2 = CS(cs2_I,:);
 
        if ~isequal(size(cs1), size(cs2))
            num_missing_res = imabsdiff(size(cs1,1), size(cs2,1));
            missing_res = zeros(num_missing_res,1);
            for j = 1:num_missing_res
                if size(cs2,1) > size(cs1,1)
                    for n = 1:size(cs2,1)
                        if ~ismember(cs2(n,2), (cs1(:,2))) && ~ismember(table2array(cs2(n,2)), missing_res)
                            missing_res(j,1) = table2array(cs2(n,2));
                            break
                        end
                    end

                else
                    for n = 1:size(cs1,1)
                        if ~ismember(cs1(n,2), (cs2(:,2))) && ~ismember(table2array(cs1(n,2)), missing_res)
                            missing_res(j,1) = table2array(cs1(n,2));
                            break
                        end
                    end
                end
            end
            while ~isequal(size(cs1), size(cs2))
                if size(cs1) == min(size(cs1), size(cs2))
                    for x = 1:size(missing_res,1)
                        missing_row = table(NaN, missing_res(x,1), string(table2array(cs1(1,3))), string(table2array(cs1(1,4))), NaN, NaN, NaN, 'VariableNames', {'atomID','resID','resName','atomName','CS','var6','chainID'});
                        cs1 = [cs1;missing_row];
                        cs1 = sortrows(cs1,2);
                        HSQCedit = 1;
                    end
                else
                    for x = 1:size(missing_res,1)
                        missing_row = table(NaN, missing_res(x,1), string(table2array(cs2(1,3))), string(table2array(cs2(1,4))), NaN, NaN, NaN, 'VariableNames', {'atomID','resID','resName','atomName','CS','var6','chainID'});
                        cs2 = [cs2;missing_row];
                        cs2 = sortrows(cs2,2);
                        HSQCedit = 1;
                    end
                end
            end
        end


        
        res = aminolookup(string(cs1.resName))';
        if i == 1
            vars = {'Assignment','hetAtom',['Het Shift (ppm)'],['Proton Shift (ppm)']};
            predHSQCtable = table(strcat(res{:}',int2str(cs1.resID),cs1.atomName),...
                cs2.atomName,...
                cs2.CS,...
                cs1.CS,...
                'VariableNames',vars);
        else
            % pad table with new residue
            vars = {'Assignment','hetAtom',['Het Shift (ppm)'],['Proton Shift (ppm)']};
            tmptable = table(strcat(res{:}',int2str(cs1.resID),cs1.atomName),...
                cs2.atomName,...
                cs2.CS,...
                cs1.CS,...
                'VariableNames',vars);
            predHSQCtable = [predHSQCtable;tmptable];
        end
    end
end
% sort by Residue
[~,I] = sort(string(predHSQCtable.Assignment));
for j = 1:size(predHSQCtable,2)
    predHSQCtable(:,j) = predHSQCtable(I,j);
end

tmpC = table2cell(predHSQCtable);
emptyRow = cell(1,4);
tmpC = [emptyRow;tmpC];
predHSQCtable = cell2table(tmpC,'VariableNames',vars);
end