% getRDCcoords -

function PCScoords = predictPCS(pdb,resTarget,proton,pcsMax,Ln)
%% predictPCS
% PCScoords = predictPCS(pdb,resTarget,proton,orderParm,Ln)
%
% Inputs
%       pdb
%       resTarget
%       proton
%       orderParm - list of scaling factors, mainly intended for combining
%       PCS and field-induced RDC measurements

% grab coordinates for spin pair of interest, e.g. 1H-15
for i = 1:size(resTarget,2)
    if ~isempty(resTarget{i})
        resI = selectname(pdb.resname,resTarget{i});


        if resTarget{i} == "ILE" && proton{i} == "HG2"
            proton{i} = 'HG21';
        end
      
        
        atom1 = find(selectname(pdb.name,proton{i}) & resI & (ismissing(cellstr(pdb.altloc)) | selectname(pdb.altloc,'A')));
        atom2 = selectname(pdb.name,Ln);
        
        % convert to one-letter amino acid code
        res = aminolookup(strtrim(pdb.resname(atom1,:)))';
        
        % define variables to package into table
        Residue = strcat(res,int2str(pdb.resseq(atom1,:)));
        atom1XYZ = pdb.xyz(atom1,:);
        atom2XYZ = pdb.xyz(atom2,:);
        atom2XYZ = ones(size(atom1XYZ,1),1) * atom2XYZ;
        
        scaleFactor = pcsMax(i)*ones(size(atom1,1),1);
        
        if i == 1
            PCScoords = table(string(Residue),...
                atom1XYZ(:,1),atom1XYZ(:,2),atom1XYZ(:,3),...
                atom2XYZ(:,1),atom2XYZ(:,2),atom2XYZ(:,3),...
                scaleFactor,...
                'VariableNames',{'Residue','x1','y1','z1',' x2','y2','z2','PCSmax'});
        else
            tmpTable = table(string(Residue),...
                atom1XYZ(:,1),atom1XYZ(:,2),atom1XYZ(:,3),...
                atom2XYZ(:,1),atom2XYZ(:,2),atom2XYZ(:,3),...
                scaleFactor,...
                'VariableNames',{'Residue','x1','y1','z1',' x2','y2','z2','PCSmax'});
            
            PCScoords = [PCScoords; tmpTable];
        end
    end
end
% sort by residue names, sortrows function seems to be broken for tables
[~,I] = sort(string(PCScoords.Residue));
for i = 1:size(PCScoords,2)
    PCScoords(:,i) = PCScoords(I,i);
end

end