%% rdcScore - calculates RDC scoring function for AssignSLPGUI
% inputs
%   x - cell array containing assignment vectors,
%           n x 1 cell array of 1x12 double
%
%   DataStruct - structure variable used throughout the AssignSLPGUI code
%
% output
%   score - vector containing scores of all assignments, n x 1 double

function [score, back_calc] = rdcScore(x,DataStruct)

score = zeros(size(x,1),1);
back_calc = zeros(DataStruct.number_measurements,size(x,1),DataStruct.number_media);

for j = 1:size(x,1)    
    d = x{j};    
    y=zeros(1,DataStruct.number_media);
    
    for media=1:DataStruct.number_media        
        % The d is a single element of the cell array.  There are
        % population_size elements of the cell array.        
        clear temp;       
                    
            total=0;
            
            % rearrange D
            D_new = DataStruct.D(media,d);
            
            D_errors = DataStruct.D(media,(DataStruct.number_measurements+1):end);
            D_errors = D_errors(d);
            
            notMissing = D_new ~=999;
            total = sum(notMissing);
            
            % filter out 'missing' residue coordinates
            x_new = DataStruct.xcoordinate(notMissing);
            y_new = DataStruct.ycoordinate(notMissing);
            z_new = DataStruct.zcoordinate(notMissing);

            % filter out missing RDCs
            D_new = D_new(notMissing);
            D_errors = D_errors(notMissing);
            D_new = D_new ./ reshape(DataStruct.order_parameters(notMissing), size(D_new));

            a = zeros(total,5);
            
            % generate matrix of independent spatial terms
            a(:,1) = (y_new.^2 - x_new.^2)';
            a(:,2) = (z_new.^2 - x_new.^2)';
            a(:,3) = 2*(x_new.*y_new)';
            a(:,4) = 2*(x_new.*z_new)';
            a(:,5) = 2*(y_new.*z_new)';
            
            a = DataStruct.Dmax(notMissing)' .* a .*vecnorm([x_new, y_new, z_new]')'.^-5;
            b = D_new; % vecnorm call calculates the magnitude of each row
            yy=lscov(a,b');   %computing projection of matrix A on b, giving x
            
            tmp_calc = a * yy;
            %tmp_calc = tmp_calc .* DataStruct.order_parameters(notMissing);
            back_calc(notMissing,j,media) = tmp_calc;
            back_calc(~notMissing,j,media) = NaN;
            
            raw_score = sqrt(sum(((tmp_calc - b') ./ D_errors').^2)/total);
            
            % scale score to account for lost degrees of freedom in
            % alignment tensor calculation
            
            % TODO what if only 5 RDCs???
            y(media) = (total-5)/DataStruct.number_measurements * raw_score;
    end  
    
    % add the media rdc,noe's    
    fitness=0;
    
    for media=1:DataStruct.number_media        
        fitness=fitness + y(media);        
    end
    
    score(j)=fitness;    
end

back_calc = permute(back_calc,[2,1,3]);

end


