%% rdcpcsScore - calculates Combined field-induced RDC & PCS scoring function for AssignSLPGUI
% inputs
%   x - cell array containing assignment vectors,
%           n x 1 cell array of 1x12 double
%
%   DataStruct - structure variable used throughout the AssignSLPGUI code
%
% output
%   score - vector containing scores of all assignments, n x 1 double

function [score, back_calc] = rdcpcsScore(x,DataStruct)

score = zeros(size(x,1),1);
nRDCPCS = size(DataStruct.RDCPCS,3);
back_calc = zeros(2*DataStruct.number_measurements,size(x,1),nRDCPCS);

for j = 1:size(x,1)    
    d = x{j};    
    y=zeros(1,nRDCPCS);
    
    for i=1:nRDCPCS       
        % The d is a single element of the cell array.  There are
        % population_size elements of the cell array.        
        clear temp;       
                    
            total=0;
            
            % reorder RDC and PCS by assignment and package into one vector
            rdcpcs = [cell2mat(DataStruct.RDCPCS(d,4,i));cell2mat(DataStruct.RDCPCS(d,2,i))];
            rdcpcs_errors = [cell2mat(DataStruct.RDCPCS(d,5,i));cell2mat(DataStruct.RDCPCS(d,3,i))];
            
            notMissing = rdcpcs ~=999;
            total = sum(notMissing);
            
            % filter out 'missing' residue coordinates
            xyz_new = cell2mat(DataStruct.RDCPCScoords(notMissing,2:7));
            x_new = xyz_new(:,1) - xyz_new(:,4);
            y_new = xyz_new(:,2) - xyz_new(:,5);
            z_new = xyz_new(:,3) - xyz_new(:,6);
            Dmax = cell2mat(DataStruct.RDCPCScoords(notMissing,8));

            % filter out missing RDCs
            rdcpcs = rdcpcs(notMissing);
            rdcpcs_errors = rdcpcs_errors(notMissing);

            if DataStruct.validation=="false"
                orderParm = cell2mat(DataStruct.RDCPCScoords(:,end));
                DS = rdcpcs./orderParm(notMissing);                        
            elseif DataStruct.validation=="true"
                DS = rdcpcs;
            end
            
            a = zeros(total,5);
            
            % generate matrix of independent spatial terms
            a(:,1) = (y_new.^2 - x_new.^2)';
            a(:,2) = (z_new.^2 - x_new.^2)';
            a(:,3) = 2*(x_new.*y_new)';
            a(:,4) = 2*(x_new.*z_new)';
            a(:,5) = 2*(y_new.*z_new)';
            
            a = Dmax .* a .*vecnorm([x_new, y_new, z_new]')'.^-5;
            b = DS; % vecnorm call calculates the magnitude of each row
            yy=lscov(a,b);   %computing projection of matrix A on b, giving x
            
            tmp_calc = a * yy;
            back_calc(notMissing,j,i) = tmp_calc;
            back_calc(~notMissing,j,i) = NaN;
            
            raw_score = sqrt(sum(((tmp_calc - b) ./ rdcpcs_errors).^2)/total);
            
            % scale score to account for lost degrees of freedom in
            % alignment tensor calculation
            
            % TODO what if only 5 RDCs???
            y(i) = (total-5)/(2*DataStruct.number_measurements) * raw_score;
    end  
    
    % add the media rdc,noe's    
    fitness=0;
    
    for i=1:DataStruct.number_media        
        fitness=fitness + y(i);        
    end
    
    score(j)=fitness;    
end

back_calc = permute(back_calc,[2,1,3]);

end


