function penalty = residuePairPenalty(x,DataStruct)
% residuePairPenalty - check that intraresidue peaks are assigned to the
% same residue

if ~isfield(DataStruct,'resPairExp')
    error('residuePairPenalty: DataStruct must contain resPairExp field!')
end

if ~isfield(DataStruct,'resPairPred')
    error('residuePairPenalty: DataStruct must contain resPairPred field!')
end

rows = size(x,1);
penalty = zeros(rows,1);

if iscell(DataStruct.resPairExp)
    resPairExp = cell2mat(DataStruct.resPairExp(:,2));
else
    resPairExp = DataStruct.resPairExp;
end

resPairPred = cell2mat(DataStruct.resPairPred(:,2));

for i = 1:rows
   d = x{i};
   n = size(d,2);
   
   for j = 1:n
       % find all peaks constrained to be in same residue
       residueNum = resPairExp(d(j));
       idx = find(resPairExp == residueNum);
       
       % are predicted counterparts also intraresidue?
       idx2 = zeros(size(idx));
       for k = 1:size(idx,1)
           idx2(k) = find(d==idx(k));
       end
       test = resPairPred(idx2);
       if all(test == test(1))
           % yes - no penalty
       else
           % no - apply penalty
           penalty(i) = penalty(i) + 1;
       end       
   end       
   
end

end